@@ -299,7 +299,7 @@ def _confirm_deploy(project, release, environment_id, wait_for_seconds, interval
         sys.exit(0)
     else:
         click.echo("")
-        click.echo(click.style(f"Deployment of {release_id} to {environment_id} failed", fg="yellow"))
+        click.echo(click.style(f"Deployment of {release_id} to {environment_id} failed", fg="red"))
         sys.exit(1)
 
 
@@ -423,8 +423,12 @@ def update(ctx, release_id, service_ids, from_label):
               help="The target environment of this deployment")
 @click.option('--description', prompt="Enter a description for this deployment",
               help="A description of this deployment", default="No description provided")
+@click.option('--confirmation-wait-for',
+              help="How many seconds to wait for a confirmation for", default=600)
+@click.option('--confirmation-interval',
+              help="How many seconds in an interval before re-confirming a deploy", default=10)
 @click.pass_context
-def release_deploy(ctx, from_label, environment_id, description):
+def release_deploy(ctx, from_label, environment_id, description, confirmation_wait_for, confirmation_interval):
     project = ctx.obj['project']
     confirm = ctx.obj['confirm']
 
@@ -442,6 +446,14 @@ def release_deploy(ctx, from_label, environment_id, description):
         confirm=confirm
     )
 
+    _confirm_deploy(
+        project=project,
+        release=release,
+        environment_id=environment_id,
+        wait_for_seconds=confirmation_wait_for,
+        interval=confirmation_interval
+    )
+
 
 @cli.command()
 @click.argument('release_id', required=False)
